.. -*- coding: utf-8 -*-

.. _contents:

==========================
PyBill Installation Manual
==========================

This document details how to install PyBill tool. PyBill is a tool that
transforms the XML description of accounting documents into PDF printable
documents. The accounting documents can be bills, claim forms, debits,
downpayments or pro-formas. PyBill can also generate accounting entries
corresponding to these documents. The accounting entries are generated in
`pycompta`_ XML format.

.. _`pycompta`: http://www.logilab.org/Project/pycompta

.. toctree::
   :maxdepth: 2

   dependencies
   manual-installation
   installable-packages

